@@ -21,11 +21,11 @@
    Authors: Ettore Perazzoli <ettore@gnu.org>, Darin Adler <darin@bentspoon.com>
 */
 
-#ifndef NAUTILUS_CANVAS_CONTAINER_H
-#define NAUTILUS_CANVAS_CONTAINER_H
+#pragma once
 
 #include <eel/eel-canvas.h>
-#include "nautilus-icon-info.h"
+
+#include "nautilus-types.h"
 
 #define NAUTILUS_TYPE_CANVAS_CONTAINER nautilus_canvas_container_get_type()
 #define NAUTILUS_CANVAS_CONTAINER(obj) \
@@ -56,12 +56,15 @@ typedef struct {
 
 #define	NAUTILUS_CANVAS_CONTAINER_TYPESELECT_FLUSH_DELAY 1000000
 
-typedef struct NautilusCanvasContainerDetails NautilusCanvasContainerDetails;
+typedef struct _NautilusCanvasContainer        NautilusCanvasContainer;
+typedef struct  NautilusCanvasContainerDetails NautilusCanvasContainerDetails;
 
-typedef struct {
+struct _NautilusCanvasContainer {
 	EelCanvas canvas;
 	NautilusCanvasContainerDetails *details;
-} NautilusCanvasContainer;
+};
+
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (NautilusCanvasContainer, g_object_unref)
 
 typedef struct {
 	EelCanvasClass parent_slot;
@@ -268,7 +271,6 @@ void              nautilus_canvas_container_set_single_click_mode         (Nauti
 									   gboolean                single_click_mode);
 void              nautilus_canvas_container_enable_linger_selection       (NautilusCanvasContainer  *view,
 									   gboolean                enable);
-void              nautilus_canvas_container_reset_scroll_region           (NautilusCanvasContainer  *container);
 void              nautilus_canvas_container_set_font                      (NautilusCanvasContainer  *container,
 									   const char             *font); 
 void              nautilus_canvas_container_set_margins                   (NautilusCanvasContainer  *container,
@@ -292,5 +294,3 @@ guint             nautilus_canvas_container_get_icon_size_for_zoom_level (Nautil
 
 #define CANVAS_HEIGHT(container,allocation) (allocation.height		\
 					     / EEL_CANVAS (container)->pixels_per_unit)
-
-#endif /* NAUTILUS_CANVAS_CONTAINER_H */
