@@ -19,8 +19,7 @@
    Author: Darin Adler <darin@bentspoon.com>
 */
 
-#ifndef NAUTILUS_FILE_PRIVATE_H
-#define NAUTILUS_FILE_PRIVATE_H
+#pragma once
 
 #include "nautilus-directory.h"
 #include "nautilus-file.h"
@@ -162,8 +161,6 @@ struct NautilusFileDetails
 
 	eel_boolean_bit mount_is_up_to_date           : 1;
 	
-	eel_boolean_bit got_link_info                 : 1;
-	eel_boolean_bit link_info_is_up_to_date       : 1;
 	eel_boolean_bit got_custom_display_name       : 1;
 	eel_boolean_bit got_custom_activation_uri     : 1;
 
@@ -172,8 +169,6 @@ struct NautilusFileDetails
 	
 	eel_boolean_bit is_thumbnailing               : 1;
 
-	eel_boolean_bit is_launcher                   : 1;
-	eel_boolean_bit is_trusted_link               : 1;
 	eel_boolean_bit is_symlink                    : 1;
 	eel_boolean_bit is_mountpoint                 : 1;
 	eel_boolean_bit is_hidden                     : 1;
@@ -199,7 +194,8 @@ struct NautilusFileDetails
 	eel_boolean_bit filesystem_readonly           : 1;
 	eel_boolean_bit filesystem_use_preview        : 2; /* GFilesystemPreviewType */
 	eel_boolean_bit filesystem_info_is_up_to_date : 1;
-        eel_ref_str     filesystem_type;
+	eel_boolean_bit filesystem_remote             : 1;
+	eel_ref_str     filesystem_type;
 
 	time_t trash_time; /* 0 is unknown */
 	time_t recency; /* 0 is unknown */
@@ -288,5 +284,3 @@ void                   nautilus_file_operation_complete (NautilusFileOperation
 							 GFile                         *result_location,
 							 GError                        *error);
 void                   nautilus_file_operation_cancel   (NautilusFileOperation         *op);
-
-#endif
