@@ -19,13 +19,12 @@
    Author: Darin Adler <darin@bentspoon.com>
 */
 
-#ifndef NAUTILUS_FILE_H
-#define NAUTILUS_FILE_H
+#pragma once
 
 #include <gtk/gtk.h>
 #include <gio/gio.h>
-#include "nautilus-file-attributes.h"
-#include "nautilus-icon-info.h"
+
+#include "nautilus-types.h"
 
 /* NautilusFile is an object used to represent a single element of a
  * NautilusDirectory. It's lightweight and relies on NautilusDirectory
@@ -123,7 +122,7 @@ typedef void (*NautilusFileOperationCallback) (NautilusFile  *file,
 					       gpointer       callback_data);
 
 
-#define NAUTILUS_FILE_ATTRIBUTES_FOR_ICON (NAUTILUS_FILE_ATTRIBUTE_INFO | NAUTILUS_FILE_ATTRIBUTE_LINK_INFO | NAUTILUS_FILE_ATTRIBUTE_THUMBNAIL)
+#define NAUTILUS_FILE_ATTRIBUTES_FOR_ICON (NAUTILUS_FILE_ATTRIBUTE_INFO | NAUTILUS_FILE_ATTRIBUTE_THUMBNAIL)
 
 typedef void NautilusFileListHandle;
 
@@ -204,7 +203,6 @@ char *                  nautilus_file_get_volume_name                   (Nautilu
 char *                  nautilus_file_get_symbolic_link_target_path     (NautilusFile                   *file);
 char *                  nautilus_file_get_symbolic_link_target_uri      (NautilusFile                   *file);
 gboolean                nautilus_file_is_broken_symbolic_link           (NautilusFile                   *file);
-gboolean                nautilus_file_is_nautilus_link                  (NautilusFile                   *file);
 gboolean                nautilus_file_is_executable                     (NautilusFile                   *file);
 gboolean                nautilus_file_is_directory                      (NautilusFile                   *file);
 gboolean                nautilus_file_is_regular_file                   (NautilusFile                   *file);
@@ -220,7 +218,6 @@ gboolean                nautilus_file_is_remote                         (Nautilu
 gboolean                nautilus_file_is_other_locations                (NautilusFile                   *file);
 gboolean                nautilus_file_is_starred_location              (NautilusFile                   *file);
 gboolean		nautilus_file_is_home				(NautilusFile                   *file);
-gboolean                nautilus_file_is_desktop_directory              (NautilusFile                   *file);
 GError *                nautilus_file_get_file_info_error               (NautilusFile                   *file);
 gboolean                nautilus_file_get_directory_item_count          (NautilusFile                   *file,
 									 guint                          *count,
@@ -251,6 +248,8 @@ char *                  nautilus_file_get_filesystem_id                 (Nautilu
 
 char *                  nautilus_file_get_filesystem_type               (NautilusFile                   *file);
 
+gboolean                nautilus_file_get_filesystem_remote             (NautilusFile                   *file);
+
 NautilusFile *          nautilus_file_get_trash_original_file           (NautilusFile                   *file);
 
 /* Permissions. */
@@ -457,14 +456,9 @@ GList                  *nautilus_file_list_filter_hidden                (GList
 /* Get the URI that's used when activating the file.
  * Getting this can require reading the contents of the file.
  */
-gboolean                nautilus_file_is_launcher                       (NautilusFile                   *file);
-gboolean                nautilus_file_is_trusted_link                   (NautilusFile                   *file);
 gboolean                nautilus_file_has_activation_uri                (NautilusFile                   *file);
 char *                  nautilus_file_get_activation_uri                (NautilusFile                   *file);
 GFile *                 nautilus_file_get_activation_location           (NautilusFile                   *file);
-
-char *                  nautilus_file_get_target_uri                    (NautilusFile                   *file);
-
 GIcon *                 nautilus_file_get_gicon                         (NautilusFile                   *file,
 									 NautilusFileIconFlags           flags);
 NautilusIconInfo *      nautilus_file_get_icon                          (NautilusFile                   *file,
@@ -616,5 +610,3 @@ typedef struct {
 
 	void                 (* poll_for_media)          (NautilusFile                   *file);
 } NautilusFileClass;
-
-#endif /* NAUTILUS_FILE_H */
