@@ -22,20 +22,12 @@
 #include <gio/gio.h>
 
 #define NAUTILUS_TYPE_PATH_BAR (nautilus_path_bar_get_type ())
-G_DECLARE_DERIVABLE_TYPE (NautilusPathBar, nautilus_path_bar, NAUTILUS, PATH_BAR, GtkContainer)
+G_DECLARE_FINAL_TYPE (NautilusPathBar, nautilus_path_bar, NAUTILUS, PATH_BAR, GtkContainer)
 
-struct _NautilusPathBarClass
-{
-	GtkContainerClass parent_class;
+void     nautilus_path_bar_set_path                       (NautilusPathBar *path_bar,
+                                                           GFile           *file);
 
-	void     (* path_clicked)   (NautilusPathBar  *self,
-				     GFile            *location);
-        void     (* open_location)  (NautilusPathBar   *self,
-                                     GFile             *location,
-                                     GtkPlacesOpenFlags flags);
-};
-void     nautilus_path_bar_set_path    (NautilusPathBar *self, GFile *file);
-void     nautilus_path_bar_set_extensions_background_menu (NautilusPathBar *self,
+void     nautilus_path_bar_set_extensions_background_menu (NautilusPathBar *path_bar,
+                                                           GMenu           *menu);
+void     nautilus_path_bar_set_templates_menu             (NautilusPathBar *path_bar,
                                                            GMenu           *menu);
-void     nautilus_path_bar_set_templates_menu (NautilusPathBar *self,
-                                               GMenu           *menu);
