@@ -25,8 +25,8 @@
 
 #include "nautilus-global-preferences.h"
 #include "nautilus-icon-info.h"
-#include "nautilus-recent.h"
-#include <eel/eel-stock-dialogs.h>
+#include "nautilus-ui-utilities.h"
+#include <eel/eel-vfs-extensions.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
@@ -36,6 +36,47 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 
+static void
+add_file_to_recent (NautilusFile *file,
+                    GAppInfo     *application)
+{
+    GtkRecentData recent_data;
+    char *uri;
+
+    uri = nautilus_file_get_activation_uri (file);
+    if (uri == NULL)
+    {
+        uri = nautilus_file_get_uri (file);
+    }
+
+    /* do not add trash:// etc */
+    if (eel_uri_is_trash (uri) ||
+        eel_uri_is_search (uri) ||
+        eel_uri_is_recent (uri))
+    {
+        g_free (uri);
+        return;
+    }
+
+    recent_data.display_name = NULL;
+    recent_data.description = NULL;
+
+    recent_data.mime_type = nautilus_file_get_mime_type (file);
+    recent_data.app_name = g_strdup (g_get_application_name ());
+    recent_data.app_exec = g_strdup (g_app_info_get_commandline (application));
+
+    recent_data.groups = NULL;
+    recent_data.is_private = FALSE;
+
+    gtk_recent_manager_add_full (gtk_recent_manager_get_default (),
+                                 uri, &recent_data);
+
+    g_free (recent_data.mime_type);
+    g_free (recent_data.app_name);
+    g_free (recent_data.app_exec);
+
+    g_free (uri);
+}
 void
 nautilus_launch_application_for_mount (GAppInfo  *app_info,
                                        GMount    *mount,
@@ -186,7 +227,7 @@ nautilus_launch_application_by_uri (GAppInfo  *application,
         for (l = uris; l != NULL; l = l->next)
         {
             file = nautilus_file_get_by_uri (l->data);
-            nautilus_recent_add_file (file, application);
+            add_file_to_recent (file, application);
             nautilus_file_unref (file);
         }
     }
@@ -335,11 +376,10 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
     {
         g_free (desktop_file_path);
         g_object_unref (desktop_file);
-        eel_show_error_dialog
-            (_("Sorry, but you cannot execute commands from "
-               "a remote site."),
-            _("This is disabled due to security considerations."),
-            parent_window);
+        show_dialog (_("Sorry, but you cannot execute commands from a remote site."),
+                     _("This is disabled due to security considerations."),
+                     parent_window,
+                     GTK_MESSAGE_ERROR);
 
         return;
     }
@@ -349,10 +389,10 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
     g_free (desktop_file_path);
     if (app_info == NULL)
     {
-        eel_show_error_dialog
-            (_("There was an error launching the application."),
-            NULL,
-            parent_window);
+        show_dialog (_("There was an error launching the application."),
+                     NULL,
+                     parent_window,
+                     GTK_MESSAGE_ERROR);
         return;
     }
 
@@ -378,11 +418,10 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
         if (count == 0)
         {
             /* all files are non-local */
-            eel_show_error_dialog
-                (_("This drop target only supports local files."),
-                _("To open non-local files copy them to a local folder and then"
-                  " drop them again."),
-                parent_window);
+            show_dialog (_("This drop target only supports local files."),
+                         _("To open non-local files copy them to a local folder and then drop them again."),
+                         parent_window,
+                         GTK_MESSAGE_ERROR);
 
             g_list_free_full (files, g_object_unref);
             g_object_unref (app_info);
@@ -391,11 +430,11 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
         else if (count != total)
         {
             /* some files are non-local */
-            eel_show_warning_dialog
-                (_("This drop target only supports local files."),
-                _("To open non-local files copy them to a local folder and then"
-                  " drop them again. The local files you dropped have already been opened."),
-                parent_window);
+            show_dialog (_("This drop target only supports local files."),
+                         _("To open non-local files copy them to a local folder and then"
+                         " drop them again. The local files you dropped have already been opened."),
+                         parent_window,
+                         GTK_MESSAGE_WARNING);
         }
     }
 
@@ -427,10 +466,10 @@ nautilus_launch_desktop_file (GdkScreen   *screen,
     if (error != NULL)
     {
         message = g_strconcat (_("Details: "), error->message, NULL);
-        eel_show_error_dialog
-            (_("There was an error launching the application."),
-            message,
-            parent_window);
+        show_dialog (_("There was an error launching the application."),
+                     message,
+                     parent_window,
+                     GTK_MESSAGE_ERROR);
 
         g_error_free (error);
         g_free (message);
