@@ -19,17 +19,14 @@
  *
  */
 
-#include <config.h>
-#include <string.h>
+#include "nautilus-query.h"
 
 #include <eel/eel-glib-extensions.h>
 #include <glib/gi18n.h>
 
-#include "nautilus-global-preferences.h"
-
-#include "nautilus-file-utilities.h"
-#include "nautilus-query.h"
 #include "nautilus-enum-types.h"
+#include "nautilus-file-utilities.h"
+#include "nautilus-global-preferences.h"
 
 #define RANK_SCALE_FACTOR 100
 #define MIN_RANK 10.0
@@ -44,12 +41,11 @@ struct _NautilusQuery
     GList *mime_types;
     gboolean show_hidden;
     GPtrArray *date_range;
+    NautilusQueryRecursive recursive;
     NautilusQuerySearchType search_type;
     NautilusQuerySearchContent search_content;
-    gboolean search_starred;
 
     gboolean searching;
-    gboolean recursive;
     char **prepared_words;
     GMutex prepared_words_mutex;
 };
@@ -119,7 +115,7 @@ nautilus_query_get_property (GObject    *object,
 
         case PROP_RECURSIVE:
         {
-            g_value_set_boolean (value, self->recursive);
+            g_value_set_enum (value, self->recursive);
         }
         break;
 
@@ -182,7 +178,7 @@ nautilus_query_set_property (GObject      *object,
 
         case PROP_RECURSIVE:
         {
-            nautilus_query_set_recursive (self, g_value_get_boolean (value));
+            nautilus_query_set_recursive (self, g_value_get_enum (value));
         }
         break;
 
@@ -273,11 +269,12 @@ nautilus_query_class_init (NautilusQueryClass *class)
      */
     g_object_class_install_property (gobject_class,
                                      PROP_RECURSIVE,
-                                     g_param_spec_boolean ("recursive",
-                                                           "Whether the query is being performed on subdirectories",
-                                                           "Whether the query is being performed on subdirectories or not",
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
+                                     g_param_spec_enum ("recursive",
+                                                        "Whether the query is being performed on subdirectories",
+                                                        "Whether the query is being performed on subdirectories or not",
+                                                        NAUTILUS_TYPE_QUERY_RECURSIVE,
+                                                        NAUTILUS_QUERY_RECURSIVE_ALWAYS,
+                                                        G_PARAM_READWRITE));
 
     /**
      * NautilusQuery::search-type:
@@ -344,7 +341,6 @@ nautilus_query_init (NautilusQuery *query)
     query->location = g_file_new_for_path (g_get_home_dir ());
     query->search_type = g_settings_get_enum (nautilus_preferences, "search-filter-time-type");
     query->search_content = NAUTILUS_QUERY_SEARCH_CONTENT_SIMPLE;
-    query->search_starred = FALSE;
     g_mutex_init (&query->prepared_words_mutex);
 }
 
@@ -552,23 +548,6 @@ nautilus_query_set_search_content (NautilusQuery              *query,
     }
 }
 
-gboolean
-nautilus_query_get_search_starred (NautilusQuery *query)
-{
-    g_return_val_if_fail (NAUTILUS_IS_QUERY (query), FALSE);
-
-    return query->search_starred;
-}
-
-void
-nautilus_query_set_search_starred (NautilusQuery *query,
-                                   gboolean       search_starred)
-{
-    g_return_if_fail (NAUTILUS_IS_QUERY (query));
-
-    query->search_starred = search_starred;
-}
-
 NautilusQuerySearchType
 nautilus_query_get_search_type (NautilusQuery *query)
 {
@@ -655,22 +634,21 @@ nautilus_query_set_searching (NautilusQuery *query,
     }
 }
 
-gboolean
+NautilusQueryRecursive
 nautilus_query_get_recursive (NautilusQuery *query)
 {
-    g_return_val_if_fail (NAUTILUS_IS_QUERY (query), FALSE);
+    g_return_val_if_fail (NAUTILUS_IS_QUERY (query),
+                          NAUTILUS_QUERY_RECURSIVE_ALWAYS);
 
     return query->recursive;
 }
 
 void
-nautilus_query_set_recursive (NautilusQuery *query,
-                              gboolean       recursive)
+nautilus_query_set_recursive (NautilusQuery          *query,
+                              NautilusQueryRecursive  recursive)
 {
     g_return_if_fail (NAUTILUS_IS_QUERY (query));
 
-    recursive = !!recursive;
-
     if (query->recursive != recursive)
     {
         query->recursive = recursive;
