@@ -36,8 +36,10 @@
 #include "nautilus-query.h"
 #include "nautilus-search-directory.h"
 
-struct NautilusSearchDirectoryFileDetails
+struct _NautilusSearchDirectoryFile
 {
+    NautilusFile parent_instance;
+
     gchar *metadata_filename;
 };
 
@@ -182,7 +184,7 @@ search_directory_file_set_metadata (NautilusFile *file,
 
     search_file = NAUTILUS_SEARCH_DIRECTORY_FILE (file);
     nautilus_keyfile_metadata_set_string (file,
-                                          search_file->details->metadata_filename,
+                                          search_file->metadata_filename,
                                           "directory", key, value);
 }
 
@@ -195,7 +197,7 @@ search_directory_file_set_metadata_as_list (NautilusFile  *file,
 
     search_file = NAUTILUS_SEARCH_DIRECTORY_FILE (file);
     nautilus_keyfile_metadata_set_stringv (file,
-                                           search_file->details->metadata_filename,
+                                           search_file->metadata_filename,
                                            "directory", key, (const gchar **) value);
 }
 
@@ -247,14 +249,10 @@ nautilus_search_directory_file_init (NautilusSearchDirectoryFile *search_file)
 
     file = NAUTILUS_FILE (search_file);
 
-    search_file->details = G_TYPE_INSTANCE_GET_PRIVATE (search_file,
-                                                        NAUTILUS_TYPE_SEARCH_DIRECTORY_FILE,
-                                                        NautilusSearchDirectoryFileDetails);
-
     xdg_dir = nautilus_get_user_directory ();
-    search_file->details->metadata_filename = g_build_filename (xdg_dir,
-                                                                "search-metadata",
-                                                                NULL);
+    search_file->metadata_filename = g_build_filename (xdg_dir,
+                                                       "search-metadata",
+                                                       NULL);
     g_free (xdg_dir);
 
     file->details->got_file_info = TRUE;
@@ -281,7 +279,7 @@ nautilus_search_directory_file_finalize (GObject *object)
 
     search_file = NAUTILUS_SEARCH_DIRECTORY_FILE (object);
 
-    g_free (search_file->details->metadata_filename);
+    g_free (search_file->metadata_filename);
 
     G_OBJECT_CLASS (nautilus_search_directory_file_parent_class)->finalize (object);
 }
@@ -309,6 +307,4 @@ nautilus_search_directory_file_class_init (NautilusSearchDirectoryFileClass *kla
     file_class->get_where_string = search_directory_file_get_where_string;
     file_class->set_metadata = search_directory_file_set_metadata;
     file_class->set_metadata_as_list = search_directory_file_set_metadata_as_list;
-
-    g_type_class_add_private (object_class, sizeof (NautilusSearchDirectoryFileDetails));
 }
