@@ -22,7 +22,7 @@
 #include <config.h>
 #include "nautilus-search-engine-tracker.h"
 
-#include "nautilus-global-preferences.h"
+#include "nautilus-search-engine-private.h"
 #include "nautilus-search-hit.h"
 #include "nautilus-search-provider.h"
 #define DEBUG_FLAG NAUTILUS_DEBUG_SEARCH
@@ -295,7 +295,6 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
     GString *sparql;
     GList *mimetypes, *l;
     gint mime_count;
-    gboolean recursive;
     GPtrArray *date_range;
 
     tracker = NAUTILUS_SEARCH_ENGINE_TRACKER (provider);
@@ -317,10 +316,6 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
         return;
     }
 
-    recursive = g_settings_get_enum (nautilus_preferences, "recursive-search") == NAUTILUS_SPEED_TRADEOFF_LOCAL_ONLY ||
-                g_settings_get_enum (nautilus_preferences, "recursive-search") == NAUTILUS_SPEED_TRADEOFF_ALWAYS;
-    tracker->recursive = recursive;
-
     tracker->fts_enabled = nautilus_query_get_search_content (tracker->query);
 
     query_text = nautilus_query_get_text (tracker->query);
@@ -354,11 +349,6 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
         g_string_append_printf (sparql, "; fts:match '\"%s\"*'", search_text);
     }
 
-    if (nautilus_query_get_search_starred (tracker->query))
-    {
-        g_string_append_printf (sparql, "; nao:hasTag nao:predefined-tag-favorite");
-    }
-
     if (mime_count > 0)
     {
         g_string_append (sparql, "; nie:mimeType ?mime");
@@ -474,13 +464,18 @@ static void
 nautilus_search_engine_tracker_set_query (NautilusSearchProvider *provider,
                                           NautilusQuery          *query)
 {
+    g_autoptr(GFile) location = NULL;
     NautilusSearchEngineTracker *tracker;
 
     tracker = NAUTILUS_SEARCH_ENGINE_TRACKER (provider);
+    location = nautilus_query_get_location (query);
 
-    g_object_ref (query);
     g_clear_object (&tracker->query);
-    tracker->query = query;
+
+    tracker->query = g_object_ref (query);
+    tracker->recursive = is_recursive_search (NAUTILUS_SEARCH_ENGINE_TYPE_INDEXED,
+                                              nautilus_query_get_recursive (query),
+                                              location);
 }
 
 static gboolean
